package com.cool.bang.modules.mysql.domain;

import oracle.sql.TIMESTAMP;

import java.math.BigDecimal;
import java.security.Timestamp;
import java.util.Date;
import java.util.Map;

/**
 * 账户表
 *
 * @author sy
 * 2022-11-08 14:58
 */
public class Account {

    private static final long serialVersionUID = 1L;

    private Long id;

    /** 银行编码 */
    private String bankCode;

    /** 银行名称 */
    private String bankName;

    /** 企业主键 */
    private Integer orgId;

    /** 企业名称 */
    private String orgName;

    /** 项目主键 */
    private Long projectId;

    /** 项目编码 */
    private String projectNumber;

    /** 项目名称 */
    private String projectName;

    /** 户名 */
    private String name;

    /** 账号 */
    private String account;

    /** 账面余额 */
    private BigDecimal bookBalance;

    /** 账户余额 */
    private BigDecimal accountBalance;

    /**
     * 非数据库字段 用于展示  总项目余额
     */
    private BigDecimal balance;

    /** 收益余额 */
    private BigDecimal incomeBalance;

    /** 在途资金 */
    private BigDecimal inTransitFund;

    /** 开户网点 */
    private String openAddress;

    /** 开户日期 */
    private Date openDate;

    /** 注销日期 */
    private Date cancelDate;

    /** 类型 1托管账户 2监管账户 3收益账户 4其他账户 */
    private Integer type;

    /** 状态 0未开户(监管状态，其他不需要) 1正常 2正在解除 3已解除 */
    private Integer state;

    /** 是否冻结 0否 1是（冻结后，只能进不能出） */
    private Integer isFrozen;

    /** 删除标识 1正常 0删除 */
    private Integer delFlag;

    public Account (){}

    public Account (Map<String,Object> map){
        this.bankCode = (String) map.get("BANKCODE");
        this.bankName = (String) map.get("BANKNAME");
        //企业信息 查询p_qyxx 通过qybh
        //账户名   查询p_qyxx 通过qybh
        this.name = (String) map.get("ACCOUNTNAME");
        this.account = (String) map.get("ACCOUNTNO");
        this.bookBalance = (BigDecimal) map.get("BOOKBALANCE");
        this.accountBalance = (BigDecimal) map.get("ACCOUNTBALANCE");
        this.incomeBalance = BigDecimal.ZERO;
        this.inTransitFund = BigDecimal.ZERO;//在途资金
        this.openAddress = (String) map.get("OPENADDRESS");
        this.openDate = (Date) map.get("KHRQ");//开户日期（取值开户申请通过日期）
        this.cancelDate = null;//注销日期 原始数据不准确
        this.type = Integer.parseInt(map.get("TYPE").toString()) == 0 ? 2 : 1;
        this.state = Integer.parseInt(map.get("JGSTATE").toString()) == 1 ? 1 : 3;
        if (map.get("FREEZE") == null){
            this.isFrozen = 0;
        }else {
            Integer freeze = Integer.parseInt(map.get("FREEZE").toString());
            this.isFrozen = freeze == 1 ? 1 : 0;
        }
//        this.delFlag = Integer.parseInt(map.get("STATE").toString()) == 1 ? 1 : 0;
        this.delFlag = 1;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public Integer getOrgId() {
        return orgId;
    }

    public void setOrgId(Integer orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(String projectNumber) {
        this.projectNumber = projectNumber;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public BigDecimal getBookBalance() {
        return bookBalance;
    }

    public void setBookBalance(BigDecimal bookBalance) {
        this.bookBalance = bookBalance;
    }

    public BigDecimal getAccountBalance() {
        return accountBalance;
    }

    public void setAccountBalance(BigDecimal accountBalance) {
        this.accountBalance = accountBalance;
    }

    public BigDecimal getIncomeBalance() {
        return incomeBalance;
    }

    public void setIncomeBalance(BigDecimal incomeBalance) {
        this.incomeBalance = incomeBalance;
    }

    public BigDecimal getInTransitFund() {
        return inTransitFund;
    }

    public void setInTransitFund(BigDecimal inTransitFund) {
        this.inTransitFund = inTransitFund;
    }

    public String getOpenAddress() {
        return openAddress;
    }

    public void setOpenAddress(String openAddress) {
        this.openAddress = openAddress;
    }

    public Date getOpenDate() {
        return openDate;
    }

    public void setOpenDate(Date openDate) {
        this.openDate = openDate;
    }

    public Date getCancelDate() {
        return cancelDate;
    }

    public void setCancelDate(Date cancelDate) {
        this.cancelDate = cancelDate;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getIsFrozen() {
        return isFrozen;
    }

    public void setIsFrozen(Integer isFrozen) {
        this.isFrozen = isFrozen;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }
}
