package com.cool.bang.modules.mysql.domain;

import com.cool.bang.modules.oracle.domain.AregItem;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 楼幢虚拟户
 *
 * @author PeiZhi Guo
 * 2022-09-27 09:36
 */
public class BuildingAccount {

    private static final long serialVersionUID = 1L;

    private Long id;

    /** 企业主键 */
    private Integer orgId;

    /** 企业名称 */
    private String orgName;

    /** 项目主键 */
    private Long projectId;

    /** 项目虚拟户 */
    private Long projectAccountId;

    /** 项目编码 */
    private String projectNumber;

    /** 项目名称 */
    private String projectName;

    /** 楼幢主键 */
    private Integer buildingId;

    /** 楼幢编码 */
    private String buildingNumber;

    /** 楼幢名称 */
    private String buildingName;

    /** 楼幢坐落 */
    private String buildingAddress;

    /** 监管面积 */
    private BigDecimal buildArea;

    /** 总套数 */
    private Integer houseNumber;

    /** 建筑成本主键 */
    private Long buildCostId;

    /** 建筑成本名称 */
    private String buildCostName;

    /** 建筑成本 */
    private BigDecimal buildCostPrice;

    /** 工程形象进度主键 */
    private Long progressId;

    /** 工程形象进度名称 */
    private String progressName;

    /** 受限比例 */
    private BigDecimal limitPercentage;

    /** 调剂比例 */
    private BigDecimal adjustmentPercentage;

    /** 银行保证函抵扣比例 */
    private BigDecimal bankPercentage;

    /** 留存比例 (受限比例-调剂比例-保函抵扣比例) */
    private BigDecimal keepPercentage;

    /** 留存金额 (监管面积 * 建筑成本 * 留存比例) */
    private BigDecimal keepAmount;

    /** 监管金额 (监管面积 * 建筑成本)  */
    private BigDecimal superviseAmount;

    /** 账户余额 */
    private BigDecimal accountBalance;

    /** 在途资金 */
    private BigDecimal inTransitFund;

    /** 额度内已拨付资金 */
    private BigDecimal inLimitFund;

    /** 解除业务主键 */
    private Long relieveId;

    /** 解除日期  */
    private String relieveDate;

    /** 是否冻结 0否 1是  */
    private Integer isFrozen;

    /** 账户类型 1托管账户 2监管账户  */
    private Integer accountType;

    /** 状态 0解除监管 1正常 2申请解除监管 */
    private Integer state;

    private Date createTime;

    /** 删除标识 1正常 0删除 */
    private Integer delFlag;

    public BuildingAccount(){}

    public BuildingAccount(Project project,AregItem aregItem){
        Building building = aregItem.getBuilding() == null ? new Building() : aregItem.getBuilding();

        this.orgId = project.getOrgId();
        this.orgName = project.getOrgName();
        this.projectId = project.getId();
        this.projectName = project.getProjectName();
        this.projectNumber = project.getProjectNumber();
        this.buildingNumber = aregItem.getLzbh();
        this.buildingId = building.getId();
        this.buildingName = building.getBuildingName();
        this.buildingAddress = building.getBuildingAddress();
        this.houseNumber = building.getHouseNumber();
        this.buildArea = aregItem.getJzmj();
        this.buildCostId = project.getBuildCostId();
        this.buildCostName = getBuildCostName();
        this.buildCostPrice = new BigDecimal(aregItem.getJazj().toString());
        this.createTime = aregItem.getLzrq();

        this.progressId = null;
        this.progressName = aregItem.getProgressname();

        this.limitPercentage = new BigDecimal(((Integer)(100 - aregItem.getPropercent())).toString());//受限比例
        this.adjustmentPercentage = new BigDecimal(aregItem.getJdpercent().toString());
        this.bankPercentage = new BigDecimal(aregItem.getBhpercent().toString());
        this.keepPercentage = aregItem.getLcbl();
        this.keepAmount = aregItem.getLcje();
        this.superviseAmount = aregItem.getJgzj();
        //this.inTransitFund = new BigDecimal("0");

        this.accountType = project.getType();
        // 若为监管项目时，楼幢虚拟户中不记录账户余额和在途资金 默认为0
        if (accountType == 2) {
            this.accountBalance = BigDecimal.ZERO;
            this.inTransitFund = BigDecimal.ZERO;
        }
        if (accountType == 1) {
            this.accountBalance = aregItem.getTgye() == null?BigDecimal.ZERO:aregItem.getTgye();
            this.inTransitFund = aregItem.getTgzt();
        }

        if (project.getType() == 1 && aregItem.getJazj().compareTo(2500) == 0) {
            this.buildCostId = 1L;
            this.buildCostName = "毛坯房";
        }
        if (project.getType() == 1 && aregItem.getJazj().compareTo(3000) == 0) {
            this.buildCostId = 2L;
            this.buildCostName = "精装房";
        }

        this.inLimitFund = BigDecimal.ZERO; //额度内已拨付资金
        this.relieveId = null; //解除业务主键
        this.relieveDate = null; //解除日期
        this.isFrozen = 0; //冻结状态 yszjjg数据不涉及冻结信息所以这个字段默认0未冻结
        this.state = aregItem.getJgState() == 1 ? 1 : 0;;
        this.delFlag = 1;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getOrgId() {
        return orgId;
    }

    public void setOrgId(Integer orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getProjectAccountId() {
        return projectAccountId;
    }

    public void setProjectAccountId(Long projectAccountId) {
        this.projectAccountId = projectAccountId;
    }

    public String getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(String projectNumber) {
        this.projectNumber = projectNumber;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Integer getBuildingId() {
        return buildingId;
    }

    public void setBuildingId(Integer buildingId) {
        this.buildingId = buildingId;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public String getBuildingName() {
        return buildingName;
    }

    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    public String getBuildingAddress() {
        return buildingAddress;
    }

    public void setBuildingAddress(String buildingAddress) {
        this.buildingAddress = buildingAddress;
    }

    public BigDecimal getBuildArea() {
        return buildArea;
    }

    public void setBuildArea(BigDecimal buildArea) {
        this.buildArea = buildArea;
    }

    public Integer getHouseNumber() {
        return houseNumber;
    }

    public void setHouseNumber(Integer houseNumber) {
        this.houseNumber = houseNumber;
    }

    public Long getBuildCostId() {
        return buildCostId;
    }

    public void setBuildCostId(Long buildCostId) {
        this.buildCostId = buildCostId;
    }

    public String getBuildCostName() {
        return buildCostName;
    }

    public void setBuildCostName(String buildCostName) {
        this.buildCostName = buildCostName;
    }

    public BigDecimal getBuildCostPrice() {
        return buildCostPrice;
    }

    public void setBuildCostPrice(BigDecimal buildCostPrice) {
        this.buildCostPrice = buildCostPrice;
    }

    public Long getProgressId() {
        return progressId;
    }

    public void setProgressId(Long progressId) {
        this.progressId = progressId;
    }

    public String getProgressName() {
        return progressName;
    }

    public void setProgressName(String progressName) {
        this.progressName = progressName;
    }

    public BigDecimal getLimitPercentage() {
        return limitPercentage;
    }

    public void setLimitPercentage(BigDecimal limitPercentage) {
        this.limitPercentage = limitPercentage;
    }

    public BigDecimal getAdjustmentPercentage() {
        return adjustmentPercentage;
    }

    public void setAdjustmentPercentage(BigDecimal adjustmentPercentage) {
        this.adjustmentPercentage = adjustmentPercentage;
    }

    public BigDecimal getBankPercentage() {
        return bankPercentage;
    }

    public void setBankPercentage(BigDecimal bankPercentage) {
        this.bankPercentage = bankPercentage;
    }

    public BigDecimal getKeepPercentage() {
        return keepPercentage;
    }

    public void setKeepPercentage(BigDecimal keepPercentage) {
        this.keepPercentage = keepPercentage;
    }

    public BigDecimal getKeepAmount() {
        return keepAmount;
    }

    public void setKeepAmount(BigDecimal keepAmount) {
        this.keepAmount = keepAmount;
    }

    public BigDecimal getSuperviseAmount() {
        return superviseAmount;
    }

    public void setSuperviseAmount(BigDecimal superviseAmount) {
        this.superviseAmount = superviseAmount;
    }

    public BigDecimal getAccountBalance() {
        return accountBalance;
    }

    public void setAccountBalance(BigDecimal accountBalance) {
        this.accountBalance = accountBalance;
    }

    public BigDecimal getInTransitFund() {
        return inTransitFund;
    }

    public void setInTransitFund(BigDecimal inTransitFund) {
        this.inTransitFund = inTransitFund;
    }

    public BigDecimal getInLimitFund() {
        return inLimitFund;
    }

    public void setInLimitFund(BigDecimal inLimitFund) {
        this.inLimitFund = inLimitFund;
    }

    public Long getRelieveId() {
        return relieveId;
    }

    public void setRelieveId(Long relieveId) {
        this.relieveId = relieveId;
    }

    public String getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(String relieveDate) {
        this.relieveDate = relieveDate;
    }

    public Integer getIsFrozen() {
        return isFrozen;
    }

    public void setIsFrozen(Integer isFrozen) {
        this.isFrozen = isFrozen;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }
}
