package com.cool.bang.modules.mysql.domain;

import com.cool.bang.common.util.DateUtil;
import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

public class FcTrade {


    private Long id;

    /**
     * 银行流水
     */
    private String serialNumber;

    /**
     * 冲红原银行流水/补录银行流水
     */
    private String flushSerialNumber;

    /**
     * 业务编码
     */
    private String businessNumber;

    /**
     * 渠道类型 1银行 2pos
     */
    private Integer channelType;

    /**
     * 渠道编码
     */
    private String channelCode;

    /**
     * 账户类型 1托管账户 2监管账户
     */
    private Integer accountType;

    /**
     * 银行账号
     */
    private String account;

    /**
     * 账户主键
     */
    private Long accountId;

    /**
     * 项目虚拟户主键
     */
    private Long projectAccountId;

    /**
     * 楼幢虚拟户主键
     */
    private Long buildingAccountId;

    /**
     * 交易金额
     */
    private BigDecimal amount;

    /**
     * 交易类型 1收入 2支出
     */
    private Integer type;

    /**
     * 交易方式 1转账 2结息 3手续费 4法院划扣 9待查入账
     */
    private Integer transactionMode;

    /**
     * 交易时间
     */
    private String transactionTime;

    /**
     * 账户余额
     */
    private BigDecimal accountBalance;

    /**
     * 对方账号
     */
    private String reciprocalAccount;

    /**
     * 对账状态 0未对账 1对账成功 2错账 3单边账
     */
    private Integer checkStatus;

    /**
     * 对账日期
     */
    private String checkDate;

    /**
     * 是否冲正 0否 1是
     */
    private Integer isFlush;

    /**
     * 删除标识 1正常 0删除
     */
    private Integer delFlag;

    private String remark;

    private Date createTime;

    private Date updateTime;

    public FcTrade(TradeInfo item, ProjectAccount projectAccount, Account account, BuildingAccount buildingAccount) {
        this.serialNumber = item.getSerialNumber();
        this.flushSerialNumber = item.getFlushSerialNumber();
        this.businessNumber = item.getBusinessNumber();
        this.channelType = item.getChannelType();
        if (null != account) {
            this.channelCode = account.getBankCode();
            this.accountType = account.getType();
            this.account = account.getAccount();
            this.accountId = account.getId();
        }
        if (null != projectAccount) {
            this.projectAccountId = projectAccount.getId();
        }
        if (null != buildingAccount) {
            this.buildingAccountId = buildingAccount.getId();
        }
        this.amount = item.getAmount();
        if (null != item.getCode()) {
            String code = String.valueOf(item.getCode());
            if (code.startsWith("1")) {//交款记账
                this.type = 1;
            } else if (code.startsWith("2")) {//退款记账
                this.type = 2;
            } else {//划拨记账 等
                this.type = 2;
            }
        }

        if (item.getPayType().equals("06")) {
            this.transactionMode = 3;
        } else if (item.getPayType().equals("05")) {
            this.transactionMode = 2;
        } else if (item.getPayType().equals("09")) {
            this.transactionMode = 1;
        } else {
            this.transactionMode = 1;
        }
        this.transactionTime = null != item.getTransactionTime() ? DateUtil.dateToStr(item.getTransactionTime(), "yyyy-MM-dd") : null;
        this.checkStatus = item.getCheckStatus();
        this.delFlag = 1;
        this.isFlush = null != item.getUndoeDate() ? 1 : 0;
        this.checkDate = null != item.getCheckDate() ? DateUtil.dateToStr(item.getCheckDate(), "yyyy-MM-dd") : null;
        this.remark = StringUtils.isEmpty(item.getRemark()) ? item.getTellErno() : item.getRemark();
        this.createTime = item.getCreateTime();
        this.updateTime = item.getCreateTime();
    }


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSerialNumber() {
        return serialNumber;
    }

    public void setSerialNumber(String serialNumber) {
        this.serialNumber = serialNumber;
    }

    public String getFlushSerialNumber() {
        return flushSerialNumber;
    }

    public void setFlushSerialNumber(String flushSerialNumber) {
        this.flushSerialNumber = flushSerialNumber;
    }

    public String getBusinessNumber() {
        return businessNumber;
    }

    public void setBusinessNumber(String businessNumber) {
        this.businessNumber = businessNumber;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getProjectAccountId() {
        return projectAccountId;
    }

    public void setProjectAccountId(Long projectAccountId) {
        this.projectAccountId = projectAccountId;
    }

    public Long getBuildingAccountId() {
        return buildingAccountId;
    }

    public void setBuildingAccountId(Long buildingAccountId) {
        this.buildingAccountId = buildingAccountId;
    }

    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getTransactionMode() {
        return transactionMode;
    }

    public void setTransactionMode(Integer transactionMode) {
        this.transactionMode = transactionMode;
    }

    public String getTransactionTime() {
        return transactionTime;
    }

    public void setTransactionTime(String transactionTime) {
        this.transactionTime = transactionTime;
    }

    public BigDecimal getAccountBalance() {
        return accountBalance;
    }

    public void setAccountBalance(BigDecimal accountBalance) {
        this.accountBalance = accountBalance;
    }

    public String getReciprocalAccount() {
        return reciprocalAccount;
    }

    public void setReciprocalAccount(String reciprocalAccount) {
        this.reciprocalAccount = reciprocalAccount;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public String getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(String checkDate) {
        this.checkDate = checkDate;
    }

    public Integer getIsFlush() {
        return isFlush;
    }

    public void setIsFlush(Integer isFlush) {
        this.isFlush = isFlush;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }
}
