package com.cool.bang.modules.mysql.domain;

import com.cool.bang.modules.oracle.domain.Areg;
import com.cool.bang.modules.oracle.domain.AregItem;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 项目虚拟户
 * @author PeiZhi Guo
 * 2022-09-05 10:24
 */
public class ProjectAccount {

    private static final long serialVersionUID = 1L;

    private Long id;

    /** yszjjg areg表id */
    private Integer aregid;

    /** 银行编码 */
    private String bankCode;

    /** 银行名称 */
    private String bankName;

    /** 企业主键 */
    private Integer orgId;

    /** 企业名称 */
    private String orgName;

    /** 项目主键 */
    private Long projectId;

    /** 项目编号 */
    private String projectNumber;

    /** 项目名称 */
    private String projectName;

    /** 项目地址 */
    private String projectAddress;

    /** 监管楼栋数 */
    private Integer buildingTotal;

    /** 监管面积 当前监管各楼栋面积和 */
    private BigDecimal buildArea;

    /** 监管金额 (楼幢监管面积 * 楼幢建筑成本) */
    private BigDecimal superviseAmount;

    /** 留存金额 (楼幢监管面积 * 楼幢建筑成本 * 楼幢留存比例)*/
    private BigDecimal keepAmount;

    /** 托管户主键 */
    private Long accountId;

    /** 托管余额 */
    private BigDecimal trusteeshipBalance;

    /** 监管余额 */
    private BigDecimal superviseBalance;

    /** 托管在途资金 */
    private BigDecimal trusteeshipInTransitFund;

    /** 监管在途资金 */
    private BigDecimal superviseInTransitFund;

    /** 共有资金 */
    // fixme 停用字段
    private BigDecimal commonFund;

    /** 建筑成本主键 */
    private Long buildCostId;

    /** 建筑成本价 */
    private String buildCostName;

    /** 解除日期  */
    private String relieveDate;

    /** 是否冻结 0否 1是 冻结后只能进不能出 */
    private Integer isFrozen;

    /** 账户类型 1托管账户 2监管账户 */
    private Integer accountType;

    /** 状态 0解除监管 1正常 2申请解除监管 */
    private Integer state;

    private Date createTime;

    /** 删除标识 1正常 0删除 */
    private Integer delFlag;

    private List<BuildingAccount> buildingAccountList;

    public ProjectAccount(){}

    public ProjectAccount(Project project, Areg areg) {

        List<AregItem> aregItemList = areg.getAregItemList();

        List<BuildingAccount> buildingAccountList = new ArrayList<>();

        //监管在途
        BigDecimal jgzt = BigDecimal.ZERO;
        //托管在途
        BigDecimal tgzt = BigDecimal.ZERO;
        //监管面积
        BigDecimal jgmj = BigDecimal.ZERO;
        //监管余额
        BigDecimal jgye = BigDecimal.ZERO;
        //托管余额
        BigDecimal tgye = BigDecimal.ZERO;

        for (AregItem aregItem : aregItemList) {
            if (aregItem != null && aregItem.getAregitemid() != null) {
                BuildingAccount buildingAccount = new BuildingAccount(project,aregItem);
                buildingAccountList.add(buildingAccount);
                jgzt = jgzt.add(aregItem.getJgzt());
                tgzt = tgzt.add(aregItem.getTgzt());
                jgmj = jgmj.add(aregItem.getJzmj());
                jgye = jgye.add(aregItem.getJgye());
                tgye = tgye.add(aregItem.getTgye());

                if (project.getType() == 1 && aregItem.getJazj().compareTo(2500) == 0) {
                    this.buildCostId = 1L;
                    this.buildCostName = "毛坯房";
                }
                if (project.getType() == 1 && aregItem.getJazj().compareTo(3000) == 0) {
                    this.buildCostId = 2L;
                    this.buildCostName = "精装房";
                }
            }
        }
        this.aregid = areg.getAregid();
        this.buildingAccountList = buildingAccountList;
        this.orgId = project.getOrgId();
        this.orgName = project.getOrgName();
        this.projectId = project.getId();
        this.projectNumber = project.getProjectNumber();
        this.projectName = project.getProjectName();
        this.projectAddress = project.getProjectAddress();
        this.buildingTotal = aregItemList.size();//监管楼栋数
        this.buildArea = jgmj;//监管面积 当前监管各楼栋面积和
        this.superviseAmount = areg.getJgje();//监管金额 (楼幢监管面积 * 楼幢建筑成本) item ZDMoney
        //this.keepAmount = areg.getLcje();//留存金额 (楼幢监管面积 * 楼幢建筑成本 * 楼幢留存比例) lcje
        this.trusteeshipBalance = tgye;//托管余额 checkbacnlce
        this.superviseBalance = jgye;//监管余额 checkjgbanlece
        this.trusteeshipInTransitFund = tgzt;//托管在途资金
        this.superviseInTransitFund = jgzt;//监管在途资金
        this.buildCostId = project.getBuildCostId();
        this.buildCostName = project.getBuildCostName();
        this.createTime = areg.getXmrq();
        this.relieveDate = null;//解除日期
        this.isFrozen = 0;//是否冻结 0否 1是 冻结后只能进不能出 yszjjg数据不涉及冻结信息所以这个字段默认0
        this.accountType = project.getType();
        this.state = areg.getJgState() == 1 ? 1 : 0;//状态 0解除监管 1正常 2申请解除监管
        this.delFlag = 1;
    }

    public Integer getAregid() {
        return aregid;
    }

    public void setAregid(Integer aregid) {
        this.aregid = aregid;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public Integer getOrgId() {
        return orgId;
    }

    public void setOrgId(Integer orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(String projectNumber) {
        this.projectNumber = projectNumber;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }

    public Integer getBuildingTotal() {
        return buildingTotal;
    }

    public void setBuildingTotal(Integer buildingTotal) {
        this.buildingTotal = buildingTotal;
    }

    public BigDecimal getBuildArea() {
        return buildArea;
    }

    public void setBuildArea(BigDecimal buildArea) {
        this.buildArea = buildArea;
    }

    public BigDecimal getSuperviseAmount() {
        return superviseAmount;
    }

    public void setSuperviseAmount(BigDecimal superviseAmount) {
        this.superviseAmount = superviseAmount;
    }

    public BigDecimal getKeepAmount() {
        return keepAmount;
    }

    public void setKeepAmount(BigDecimal keepAmount) {
        this.keepAmount = keepAmount;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public BigDecimal getTrusteeshipBalance() {
        return trusteeshipBalance;
    }

    public void setTrusteeshipBalance(BigDecimal trusteeshipBalance) {
        this.trusteeshipBalance = trusteeshipBalance;
    }

    public BigDecimal getSuperviseBalance() {
        return superviseBalance;
    }

    public void setSuperviseBalance(BigDecimal superviseBalance) {
        this.superviseBalance = superviseBalance;
    }

    public BigDecimal getTrusteeshipInTransitFund() {
        return trusteeshipInTransitFund;
    }

    public void setTrusteeshipInTransitFund(BigDecimal trusteeshipInTransitFund) {
        this.trusteeshipInTransitFund = trusteeshipInTransitFund;
    }

    public BigDecimal getSuperviseInTransitFund() {
        return superviseInTransitFund;
    }

    public void setSuperviseInTransitFund(BigDecimal superviseInTransitFund) {
        this.superviseInTransitFund = superviseInTransitFund;
    }

    public BigDecimal getCommonFund() {
        return commonFund;
    }

    public void setCommonFund(BigDecimal commonFund) {
        this.commonFund = commonFund;
    }

    public Long getBuildCostId() {
        return buildCostId;
    }

    public void setBuildCostId(Long buildCostId) {
        this.buildCostId = buildCostId;
    }

    public String getBuildCostName() {
        return buildCostName;
    }

    public void setBuildCostName(String buildCostName) {
        this.buildCostName = buildCostName;
    }

    public String getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(String relieveDate) {
        this.relieveDate = relieveDate;
    }

    public Integer getIsFrozen() {
        return isFrozen;
    }

    public void setIsFrozen(Integer isFrozen) {
        this.isFrozen = isFrozen;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }

    public List<BuildingAccount> getBuildingAccountList() {
        return buildingAccountList;
    }

    public void setBuildingAccountList(List<BuildingAccount> buildingAccountList) {
        this.buildingAccountList = buildingAccountList;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}
