package com.cool.bang.modules.mysql.service;

import com.alibaba.druid.support.json.JSONUtils;
import com.cool.bang.common.util.DateUtil;
import com.cool.bang.modules.mysql.domain.*;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalFlow;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalNode;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalRecord;
import com.cool.bang.modules.mysql.mapper.*;
import com.cool.bang.modules.oracle.domain.*;
import com.cool.bang.modules.oracle.domain.po.*;
import com.cool.bang.modules.oracle.mapper.*;
import com.sun.org.apache.bcel.internal.generic.RETURN;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import javax.swing.event.ListDataEvent;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.Stream;

@Service
public class MySQLService {

    @Autowired
    private MySqlMapper mySqlMapper;
    @Autowired
    private OracleMapper oracleMapper;
    @Autowired
    private OrgMapper qyxxMapper;
    @Autowired
    private BankMapper bankMapper;
    @Autowired
    private ProjectMapper projectMapper;
    @Autowired
    private AccountMapper accountMapper;
    @Autowired
    private AregMapper aregMapper;
    @Autowired
    private BuildingMapper buildingMapper;
    @Autowired
    private ProjectAccountMapper projectAccountMapper;
    @Autowired
    private BuildingAccountMapper buildingAccountMapper;
    @Autowired
    private BxmxyMapper bxmxyMapper;
    @Autowired
    private FlowMapper flowMapper;
    @Autowired
    private SysUserMapper userMapper;
    @Autowired
    private TrusteeshipMapper trusteeshipMapper;
    @Autowired
    private ApplyMapper applyMapper;
    @Autowired
    private TradeMapper tradeMapper;
    @Autowired
    private ProgressConfigMapper progressConfigMapper;
    @Autowired
    private FWMapper fwMapper;

    /**
     * 项目表 数据匹配
     */
    @Transactional
    public void project() {
        //对应YSZJJG--BXM表

        System.out.println("===============fc_project 数据匹配开始=================");
        List<Map<String, Object>> list = oracleMapper.selectFromBxm();

        List<Project> projectList = new ArrayList<>();
        for (Map<String, Object> map : list) {
            Integer JGZT = Integer.parseInt(map.get("JGZT").toString());
            if (JGZT == 0) {
                continue;
            }
            Project project = new Project(map);
            List<Map<String, Object>> aregs = oracleMapper.selectAregByXmbh((String) map.get("XMBH"));
            boolean jg = false;
            if (aregs.size() == 1) {
                String jsstate = (String) aregs.get(0).get("JGSTATE");
                if (jsstate.equals("-1")) {
                    project.setState(0);
                }
                if (jsstate.equals("1")) {
                    project.setState(1);
                }
            } else {
                for (Map<String, Object> areg : aregs) {
                    String jsstate = (String) areg.get("JGSTATE");
                    if (jsstate.equals("1")) {
                        jg = true;
                    }
                }
                project.setState(jg ? 1 : 0);
            }

            Org org = qyxxMapper.selectOrgByMisid(Integer.parseInt(map.get("QYBH").toString().trim()));
//            if (org == null){
//                project.setOrgId(0);
//            }else {
            project.setOrgId(org.getId());
//            }
            // 查询该项目下房屋总套数
            Integer houseTotal = projectMapper.selectProjectHouseTotal(project.getProjectNumber());
            project.setHouseTotal(houseTotal == null ? 0 : houseTotal);
            projectList.add(project);
        }
        int i = projectMapper.insertProject(projectList);
        mySqlMapper.updateProjectStatus();
        System.out.println("===============fc_project 数据匹配结束==插入" + i + "条数据==============");
    }


    /**
     * 账户表 数据匹配
     */
    public void account() {
        //对应ACCOUNT表
        System.out.println("===============fc_account 数据匹配开始=================");
        List<Map<String, Object>> list = oracleMapper.selectFromAccount();

        List<Account> accountList = new ArrayList<>();
        for (Map<String, Object> map : list) {
            Account account = new Account(map);
            if (map.get("QYBH") != null) {
                Org org = qyxxMapper.selectOrgByMisid(Integer.parseInt(map.get("QYBH").toString().trim()));
                account.setOrgId(org.getId());
                account.setOrgName(org.getOrgName());
                account.setName(org.getOrgName());
            }
            if (map.get("XMBH") != null) {
                Project project = projectMapper.selectByProjectNumber((String) map.get("XMBH"));
                if (project != null) {
                    account.setProjectId(project.getId());
                    account.setProjectName(project.getProjectName());
                    account.setProjectNumber(project.getProjectNumber());
                }
            }
            //查询账户在途资金
            BigDecimal inTransitFund = oracleMapper.selectAccountInTransitFund(Integer.parseInt(map.get("ACCOUNTID").toString()));
            if (inTransitFund != null) {
                account.setInTransitFund(inTransitFund);
            }
            accountList.add(account);
        }
        int i = accountMapper.insertAccount(accountList);

        //查询账号的数据
        List<Long> ids = accountMapper.selectReuseAcoount();
        for (Long id : ids) {
            accountMapper.deleteById(id);
        }

        System.out.println("===============fc_account 数据匹配结束==插入" + i + "条数据==============");
    }


    /**
     * 项目账户表 楼幢账户表 数据匹配
     */
    @Transactional
    public void projectAccount() {
        //对应YSZJJG--AREG、AREGITEM表
        System.out.println("===============fc_project_account fc_building_account数据匹配开始=================");

        //从yszjjg库查询项目虚拟户以及楼幢虚拟户
        List<Areg> aregList = aregMapper.selectFromAreg();

        for (Areg areg : aregList) {
            List<AregItem> aregItemList = areg.getAregItemList();
            for (AregItem aregItem : aregItemList) {
                if (aregItem.getAregitemid() != null) {
                    //查询楼幢信息
                    Building building = buildingMapper.selectByBuildingNumber(aregItem.getLzbh());
                    aregItem.setBuilding(building);
                    //查询楼幢虚拟户托管、监管在途资金
                    System.out.println();
                    aregItem.setTgzt(aregMapper.selectLzTgzt(aregItem.getAregitemid()));
                    aregItem.setJgzt(aregMapper.selectLzJgzt(aregItem.getAregitemid()));
                }
            }

            //查询项目信息
            Project project = projectMapper.selectByProjectNumber(areg.getXmbh());
            ProjectAccount projectAccount = new ProjectAccount(project, areg);
            if (areg.getTgzh() != null) {
                Account account = accountMapper.selectByAccountNO(areg.getTgzh());
                projectAccount.setBankCode(account.getBankCode());
                projectAccount.setBankName(account.getBankName());
                projectAccount.setAccountId(account.getId());
            }

            //插入
            int i = projectAccountMapper.insertProjectAccount(projectAccount);
            System.out.println("*******************");
            System.out.println(projectAccount.getProjectName() + "插入完成");
            if (projectAccount.getBuildingAccountList().size() > 0) {
                int n = buildingAccountMapper.insertBuildingAccount(projectAccount.getId(), projectAccount.getBuildingAccountList());
                System.out.println("插入楼幢虚拟户数据" + n + "条");
            }
            // 更新每个项目虚拟户留存金额
            projectAccountMapper.updateKeepAmount(projectAccount.getId());
            if (projectAccount.getAccountType() == 1) {
                projectAccountMapper.updateTrusteeshipInTransit(projectAccount.getId());
            }
            if (projectAccount.getAccountType() == 2) {
                projectAccountMapper.updateSuperviseInTransit(projectAccount.getId());
            }
            System.out.println("*******************");
        }
        // 更新楼幢相关数据
        projectMapper.updateBuildArea();
        projectMapper.updateBuildTotal();
        System.out.println("===============fc_project_account fc_building_account数据匹配结束==============");
    }

    /**
     * 托管申请表 托管协议表 导入 托管申请的APPTYPE = 0
     */
    @Transactional
    public void trusteeshipBusiness() {
        System.out.println("===============fc_trusteeship_agreement fc_trusteeship_business 数据匹配开始=================");

        List<Bxmxy> xmxyList = bxmxyMapper.selectFromBxmxy();

        System.out.println("查询出项目协议信息共"+ xmxyList.size() + "条");

        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(1); //托管申请flowType = 1
        //查询节点信息
        List<ApprovalNode> nodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());

        for (Bxmxy bxmxy : xmxyList) {
            Project project = projectMapper.selectByProjectNumber(bxmxy.getXmbh());
            Org org = qyxxMapper.selectOrgByMisid(Integer.valueOf(bxmxy.getQybh()));
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }

            TrusteeshipBusiness trusteeshipBusiness = new TrusteeshipBusiness(project, org, bxmxy);

            trusteeshipBusiness.setFlowNumber(approvalFlow.getFlowNumber());

            if (bxmxy.getBljd() == 1) { //申请
                // 添加开始节点
                ApprovalNode approvalNode = nodeList.get(0);
                trusteeshipBusiness.setFlowNodeId(approvalNode.getNextNodeId());
                trusteeshipBusiness.setFlowNodeName(approvalNode.getNodeName());
                trusteeshipMapper.insertTrusteeshipBusiness(trusteeshipBusiness);

                // 添加审批记录
                ApprovalRecord approvalRecord = new ApprovalRecord();
                approvalRecord.setBusinessNumber(trusteeshipBusiness.getBusinessNumber());
                approvalRecord.setFlowNumber(trusteeshipBusiness.getFlowNumber());
                approvalRecord.setTableId(trusteeshipBusiness.getId());
                approvalRecord.setNodeId(trusteeshipBusiness.getFlowNodeId());
                approvalRecord.setNodeName(trusteeshipBusiness.getFlowNodeName());
                approvalRecord.setApprover(org.getOrgName());
                approvalRecord.setApprovalTime(DateUtil.strToDate(bxmxy.getSqsj(), "yyyy-MM-dd HH:mm:ss"));
                approvalRecord.setDelFlag(1);
                flowMapper.insertRecord(approvalRecord);
            } else { //已经审核
                // 开始节点
                ApprovalNode startNode = nodeList.get(0);
                // 结束节点
                ApprovalNode endNode = nodeList.get(1);

                trusteeshipBusiness.setFlowNodeId(nodeList.get(2).getId());
                trusteeshipBusiness.setFlowNodeName(nodeList.get(2).getNodeName());
                trusteeshipMapper.insertTrusteeshipBusiness(trusteeshipBusiness);

                // 添加审批记录
                ApprovalRecord startNodeRecord = new ApprovalRecord();
                startNodeRecord.setBusinessNumber(trusteeshipBusiness.getBusinessNumber());
                startNodeRecord.setFlowNumber(trusteeshipBusiness.getFlowNumber());
                startNodeRecord.setTableId(trusteeshipBusiness.getId());
                startNodeRecord.setNodeId(startNode.getId());
                startNodeRecord.setNodeName(startNode.getNodeName());
                startNodeRecord.setApprover(org.getOrgName());
                startNodeRecord.setApprovalTime(DateUtil.strToDate(bxmxy.getSqsj(), "yyyy-MM-dd HH:mm:ss"));
                startNodeRecord.setDelFlag(1);
                flowMapper.insertRecord(startNodeRecord);

                ApprovalRecord endNodeRecord = new ApprovalRecord();
                endNodeRecord.setBusinessNumber(trusteeshipBusiness.getBusinessNumber());
                endNodeRecord.setFlowNumber(trusteeshipBusiness.getFlowNumber());
                endNodeRecord.setTableId(trusteeshipBusiness.getId());
                endNodeRecord.setNodeId(endNode.getId());
                endNodeRecord.setNodeName(endNode.getNodeName());
                endNodeRecord.setApproverId(null);
                endNodeRecord.setApprover("监管部门");
                endNodeRecord.setApprovalTime(DateUtil.strToDate(bxmxy.getShsj(), "yyyy-MM-dd HH:mm:ss"));
                endNodeRecord.setApprovalStatus(1);
                endNodeRecord.setApprovalRemark("无");
                endNodeRecord.setDelFlag(1);
                flowMapper.insertRecord(endNodeRecord);

                //已经审核通过的添加托管协议信息、签章信息
                TrusteeshipAgreement trusteeshipAgreement = new TrusteeshipAgreement(trusteeshipBusiness, bxmxy);

                String tgzh = bxmxy.getTgzh();
                if (tgzh != null) {
                    if (tgzh.contains(",")) {//是否包含逗号，包含的说明两家托管银行
                        String[] arr = tgzh.split(",");
                        Account account1 = accountMapper.selectByAccountNO(arr[0]);
                        trusteeshipAgreement.setTrusteeship0AccountId(account1.getId());
                        trusteeshipAgreement.setTrusteeship0Account(account1.getAccount());
                        trusteeshipAgreement.setTrusteeship0Bank(account1.getBankName());
                        trusteeshipAgreement.setTrusteeship0BankCode(account1.getBankCode());
                        trusteeshipAgreement.setTrusteeship0Range(bxmxy.getJgld());

                        Account account2 = accountMapper.selectByAccountNO(arr[1]);
                        trusteeshipAgreement.setTrusteeship1AccountId(account2.getId());
                        trusteeshipAgreement.setTrusteeship1Account(account2.getAccount());
                        trusteeshipAgreement.setTrusteeship1Bank(account2.getBankName());
                        trusteeshipAgreement.setTrusteeship1BankCode(account2.getBankCode());
                        trusteeshipAgreement.setTrusteeship1Range(bxmxy.getJgld());
                    } else {
                        Account account = accountMapper.selectByAccountNO(tgzh);
                        trusteeshipAgreement.setTrusteeship0AccountId(account.getId());
                    }
                }
                trusteeshipMapper.insertTrusteeshipAgreement(trusteeshipAgreement);

                //需要判断 什么时候插入的签章信息
                if (bxmxy.getCadocid() != null && bxmxy.getCaxyid() != null) {
                    Signatory signatory = new Signatory(bxmxy,trusteeshipAgreement);
                    List<Signatory> signatoryList = new ArrayList<>();
                    signatoryList.add(signatory.getSignatory());
                    signatoryList.add(signatory.getSignatory2());
                    trusteeshipMapper.insertSignatory(signatoryList);
                }
            }
        }
        System.out.println("===============fc_trusteeship_agreement fc_trusteeship_business 数据匹配结束=================");
    }

    /**
     * 监管开户申请业务表导入
     */
    @Transactional
    public void superviseBusiness() {
        System.out.println("===============fc_supervise_business数据匹配开始=================");

        List<Jgyw> jgywList = applyMapper.selectJgkh();

        List<SuperviseBusiness> superviseBusinessList = new ArrayList<>();
        for (Jgyw jgyw : jgywList) {
            Project project = projectMapper.selectByProjectNumber(jgyw.getXmbh());

            Account account = accountMapper.selectByAccountNO(jgyw.getAccountno());
            Org org = qyxxMapper.selectOrgByMisid(jgyw.getQybh());
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }


            SuperviseBusiness superviseBusiness = new SuperviseBusiness(account, org, project, jgyw);

            superviseBusinessList.add(superviseBusiness);
        }
        int i = mySqlMapper.insertSuperviseBusiness(superviseBusinessList);

        System.out.println("===============fc_supervise_business数据匹配结束 插入数据" + i + "条==============");
    }

    /**
     * 项目解除，账户解除
     */
    @Transactional
    public void relieve() {
        List<OracleRelieve> oracleRelieves = applyMapper.selectRelieves();

        // 查询审批流程
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(7); // 解除申请flowId = 7
        List<ApprovalNode> nodes = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        ApprovalNode endNode = new ApprovalNode();
        for (ApprovalNode node : nodes) {
            if (node.getNumber() == 3) {
                endNode = node;
            }
        }

        for (OracleRelieve oracleRelieve : oracleRelieves) {

            // 审核不通过的，不导入
            if (oracleRelieve.getFlowState().equals(1) &&
                    oracleRelieve.getFlowNodeName().equals("解除监管初审不通过")) {
                continue;
            }

            Relieve relieve = new Relieve(oracleRelieve);

            // 申请未审核的导入
            if (oracleRelieve.getFlowState().equals(1) &&
                    oracleRelieve.getFlowNodeName().equals("解除监管申请上报")) {
                relieve.setBusinessState(1);
            } else if (oracleRelieve.getFlowState().equals(1)) {
                throw new RuntimeException("解除项目异常：" + oracleRelieve.getFlowNodeName());
            }

            // 审核已完成
            if (oracleRelieve.getFlowState().equals(0)) {
                relieve.setBusinessState(3);
            }

            Org org = qyxxMapper.selectOrgByMisid(oracleRelieve.getOrgMisId());
            relieve.setOrgId(org.getId());
            relieve.setOrgName(org.getOrgName());

            Project project = projectMapper.selectByProjectNumber(oracleRelieve.getProjectNumber());
            relieve.setProjectId(project.getId());
            relieve.setProjectNumber(project.getProjectNumber());
            relieve.setProjectName(project.getProjectName());

            relieve.setFlowNumber(approvalFlow.getFlowNumber());
            relieve.setFlowNodeId(endNode.getId());
            relieve.setFlowNodeName(endNode.getNodeName());

            // 判断项目虚拟户是否已全部解除
            List<Areg> list = applyMapper.selectIsRelieve(relieve.getProjectNumber());
            if (list.size() == 1) {
                relieve.setRelieveType(1); // 项目解除
                // 如果是未审核通过的，改为解除中
                if (oracleRelieve.getFlowState().equals(1)) {
                    projectMapper.updateRelieve(relieve.getProjectId(), 2);
                } else {
                    projectMapper.updateRelieve(relieve.getProjectId(), 0);
                }
            } else {
                relieve.setRelieveType(2);
            }
            mySqlMapper.insertRelieve(relieve);

            // ------------------------------ 项目解除详情 ----------------------------------

            List<RelieveDetail> relieveDetails = new ArrayList<>();
            List<OracleRelieveDetail> oracleRelieveDetails = applyMapper.selectRelieveDetails(oracleRelieve.getAppId());
            if (oracleRelieveDetails != null  && oracleRelieveDetails.size() > 0
                    && oracleRelieveDetails.get(0) != null  && !StringUtils.isEmpty(oracleRelieveDetails.get(0).getBuildingNumber())) {
                StringBuilder relieveBuilding = new StringBuilder();
                for (OracleRelieveDetail detail : oracleRelieveDetails) {
                    BuildingAccount building = buildingAccountMapper.selectByBuildingNumber(detail.getBuildingNumber());
                    RelieveDetail relieveDetail = new RelieveDetail(building);
                    relieveDetail.setRelieveId(relieve.getId());
                    relieveDetails.add(relieveDetail);
                    relieveBuilding.append(building.getBuildingName()).append(",");
                }
                String buildingNames = relieveBuilding.toString().substring(0, relieveBuilding.length() -1);
                mySqlMapper.updateRelieveBuilding(relieve.getId(), buildingNames);
                mySqlMapper.insertRelieveDetail(relieveDetails);
                buildingAccountMapper.updateRelieve(relieveDetails, relieve.getUpdateTime());
            }


            // ------------------------------ 项目解除审批记录 ----------------------------------

            List<ApprovalRecord> approvalRecords = new ArrayList<>();
            List<OracleApprovalRecord> oracleApprovalRecords =  applyMapper.selectRelieveRecord(oracleRelieve.getAppId());
            for (OracleApprovalRecord approval : oracleApprovalRecords) {
                ApprovalRecord record = new ApprovalRecord();
                record.setBusinessNumber(relieve.getBusinessNumber());
                record.setFlowNumber(relieve.getFlowNumber());
                record.setTableId(relieve.getId());
                record.setApprovalTime(approval.getApprovalTime());
                record.setApprovalRemark(approval.getRemark());
                record.setCreateTime(record.getApprovalTime());
                record.setUpdateTime(record.getApprovalTime());
                record.setDelFlag(1);
                if (StringUtils.isEmpty(approval.getApprovalStatus())) {
                    record.setNodeName("申请节点");
                    record.setApprover(relieve.getOrgName() + "(" + approval.getApprover() + ")");
                } else {
                    record.setNodeName(approval.getNodeName());
                    record.setApprover("监管部门(" + approval.getApprover() + ")");
                    if (approval.getApprovalStatus().equals("1")) {
                        record.setApprovalStatus(1);
                    } else {
                        record.setApprovalStatus(2);
                    }
                }
                approvalRecords.add(record);
            }
            flowMapper.insertRecordBatch(approvalRecords);

            // ------------------------------ 监管账户解除 ----------------------------------

            /*
             * 查询oracle监管账户，根据监管账户查询mysql账户信息，声明监管账户解除业务并插入mysql，更新账户表账户解除日期
             */
            List<OracleAccount> oracleAccounts = applyMapper.selectRelieveSuperviseAccount(oracleRelieve.getAppId());

            for (OracleAccount oracleAccount : oracleAccounts) {
                if (oracleAccount != null && !StringUtils.isEmpty(oracleAccount.getAccount())) {
                    Account account = accountMapper.selectByAccountNO(oracleAccount.getAccount());
                    SuperviseRelieve superviseRelieve = new SuperviseRelieve(account, org, project, oracleRelieve);
                    mySqlMapper.insertSuperviseRelieve(superviseRelieve);
                    // 更新账户解除日期
                    accountMapper.updateCancelDate(account.getId(), superviseRelieve.getUpdateTime());
                }
            }
        }
    }

    /**
     * 监管账户解除业务表导入
     */
    /*@Transactional
    public void superviseRelieve(){
        System.out.println("===============fc_supervise_relieve数据匹配开始=================");

        List<Jgyw> jgywList = applyMapper.selectJgjc();

        List<SuperviseRelieve> superviseRelieveList = new ArrayList<>();
        for (Jgyw jgyw : jgywList) {
            Account account = accountMapper.selectByAccountNO(jgyw.getAccountno());
            Org org = qyxxMapper.selectOrgByMisid(jgyw.getQybh());
            if (org == null){ //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            Project project = projectMapper.selectByProjectNumber(jgyw.getXmbh());

            SuperviseRelieve superviseRelieve = new SuperviseRelieve(account,org,project,jgyw);

            superviseRelieveList.add(superviseRelieve);

            //更新账户解除日期
            accountMapper.updateCancelDate(account.getId(),superviseRelieve.getUpdateTime());
        }
        int i = mySqlMapper.insertSuperviseRelieve(superviseRelieveList);

        System.out.println("===============fc_supervise_relieve数据匹配结束 插入数据"+i+"条==============");
    }*/

    /**
     * 监管资金转托管业务表、明细表导入
     */
    @Transactional
    public void superviseTo() {
        System.out.println("=============== 监管资金转托管 =================");
        List<Jgztg> jgztgList = applyMapper.selectJgztg();

        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(5); //监管资金转托管flowType = 5
        //查询结束节点 节点信息
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        ApprovalNode currentNode = new ApprovalNode();
        for (ApprovalNode approvalNode : approvalNodeList) {
            if (approvalNode.getNodeName().equals("流程结束")) {
                currentNode = approvalNode;
            }
        }

        List<SuperviseToDetail> superviseToDetailList = new ArrayList<>();
        List<ApprovalRecord> recordList = new ArrayList<>();
        List<SuperviseToOutgoing> superviseToOutgoingList = new ArrayList<>();
        List<SuperviseToPosting> superviseToPostingList = new ArrayList<>();
        for (Jgztg jgztg : jgztgList) {
            Account superviseAccount = accountMapper.selectByAccountNO(jgztg.getJgzh());
            Account trusteeshipAccount = accountMapper.selectByAccountNO(jgztg.getTgzh());
            Org org = qyxxMapper.selectOrgByMisid(jgztg.getQybh());
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            Project project = projectMapper.selectByProjectNumber(jgztg.getXmbh());

            //业务表
            SuperviseTo superviseTo = new SuperviseTo(superviseAccount, trusteeshipAccount, org, project, jgztg);
            superviseTo.setFlowNumber(approvalFlow.getFlowNumber());
            superviseTo.setFlowNodeId(currentNode.getId());
            superviseTo.setFlowNodeName(currentNode.getNodeName());
            mySqlMapper.insertSuperviseTo(superviseTo);

            //明细表
            List<Jgztgmx> jgztgmxList = jgztg.getJgztgmxList();
            for (Jgztgmx jgztgmx : jgztgmxList) {
                BuildingAccount buildingAccount = buildingAccountMapper.selectByBuildingNumber(jgztgmx.getLzbh());
                SuperviseToDetail superviseToDetail = new SuperviseToDetail(buildingAccount, jgztgmx);
                superviseToDetail.setSuperviseToId(superviseTo.getId());
                superviseToDetail.setCreateTime(superviseTo.getCreateTime());
                superviseToDetail.setUpdateTime(superviseTo.getUpdateTime());
                superviseToDetailList.add(superviseToDetail);
            }

            //查询交易信息
            Trade trade = new Trade();
            trade.setTradenum(jgztg.getPaycode());
            trade.setTradestate("1");
            List<Trade> trades = tradeMapper.selectFromTrade(trade);
            //出账记录
            Trade tradeCz = new Trade();
            //入账记录
            Trade tradeRz = new Trade();
            for (Trade t : trades) {
                if (t.getTradecode().equals("1002")) {
                    tradeRz = t;
                } else if (t.getTradecode().equals("3002")) {
                    tradeCz = t;
                }
            }
            //出账通知书
            SuperviseToNotice superviseToNotice = new SuperviseToNotice();
            superviseToNotice.initNotice(superviseTo);

            SuperviseToOutgoing superviseToOutgoing = new SuperviseToOutgoing();
            superviseToOutgoing.initNotice(superviseTo);
            superviseToOutgoing.setBusinessNumber(jgztg.getPaycode());
            if (tradeCz.getId() != null) {
                superviseToOutgoing.setAppropriationStatus(1);
                superviseToOutgoing.setUpdateTime(DateUtil.dateToStr(tradeCz.getTradedate(), "yyyy-MM-dd HH:mm:ss"));
            } else {
                superviseToOutgoing.setAppropriationStatus(0);
            }
            superviseToOutgoingList.add(superviseToOutgoing);

            //入账通知书
            SuperviseToPosting superviseToPosting = new SuperviseToPosting();
            superviseToPosting.initNotice(superviseTo);
            superviseToPosting.setBusinessNumber(jgztg.getPaycode());
            if (tradeRz.getId() != null) {
                superviseToPosting.setPostingStatus(1);
                superviseToPosting.setUpdateTime(DateUtil.dateToStr(tradeCz.getTradedate(), "yyyy-MM-dd HH:mm:ss"));
            } else {
                superviseToPosting.setPostingStatus(0);
            }
            superviseToPostingList.add(superviseToPosting);

            for (SFlow sFlow : jgztg.getsFlowList()) {
                ApprovalRecord record = new ApprovalRecord();
                record.setBusinessNumber(jgztg.getYwbh());
                record.setFlowNumber(approvalFlow.getFlowNumber());
                record.setTableId(superviseTo.getId());
                record.setApprovalTime(sFlow.getShsj());
                record.setApprovalRemark(sFlow.getBz());
                record.setCreateTime(record.getApprovalTime());
                record.setUpdateTime(record.getApprovalTime());
                record.setDelFlag(1);
                if (sFlow.getLcmc().equals("监管资金转托管申请上报")) {
                    record.setNodeName("申请节点");
                    record.setApprover(org.getOrgName() + "(" + sFlow.getShr() + ")");
                } else {
                    record.setNodeName(sFlow.getLcmc());
                    record.setApprover("监管部门(" + sFlow.getShr() + ")");
                    record.setApprovalStatus(1);
                }
                recordList.add(record);
            }
        }
        mySqlMapper.insertSuperviseToDetail(superviseToDetailList);
        recordList.forEach(item -> System.out.println(">>>>>> item ===" + item));
        flowMapper.insertRecordBatch(recordList);
        mySqlMapper.insertSuperviseToPosting(superviseToPostingList);
        mySqlMapper.insertSuperviseToOutgoing(superviseToOutgoingList);
    }

    /**
     * 工程形象进度业务表、明细表导入
     */
    @Transactional
    public void progressBusiness() {
        System.out.println("===============fc_progress_business、fc_progress_detail数据匹配开始=================");
        Long a = new Date().getTime();
        List<Gcjdsq> gcjdsqList = oracleMapper.selectPromProgress();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("耗时");
        System.out.println((b - a) / 1000);

        Gcjdsq lastGcjdsq = gcjdsqList.get(gcjdsqList.size() - 1);

        //查询版本号为1的工程进度标准
        List<ProgressConfig> progressConfigList = progressConfigMapper.selectByVersion(1);
        //当前申请节点
        ProgressConfig currProgressConfig = new ProgressConfig();
        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(2); //工程形象进度申请flowType = 2
        //查询结束节点 节点信息
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());

        ApprovalNode node1 = approvalNodeList.get(0);
        ApprovalNode node2 = approvalNodeList.get(1);
        ApprovalNode node3 = approvalNodeList.get(2);

        List<ApprovalRecord> recordList = new ArrayList<>();

        List<ProgressDetail> progressDetailList = new ArrayList<>();

        int index = 0;
        for (Gcjdsq gcjdsq : gcjdsqList) {

            Org org = qyxxMapper.selectOrgByMisid(gcjdsq.getQybh());
            BuildingAccount buildingAccount = buildingAccountMapper.selectByBuildingNumber(gcjdsq.getLzbh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(gcjdsq.getAregid());

            for (ProgressConfig progressConfig : progressConfigList) {
                if (progressConfig.getLimitPercentage().compareTo(new BigDecimal("100").subtract(gcjdsq.getSqjd())) == 0) {
                    currProgressConfig = progressConfig;
                }
            }

            Progress progress = new Progress(org, projectAccount, gcjdsq);
            progress.setFlowNumber(approvalFlow.getFlowNumber());

            if (progress.getBusinessState() == 1) { //待审核
                progress.setFlowNodeId(node2.getId());
                progress.setFlowNodeName(node1.getNodeName());
                mySqlMapper.insertProgress(progress);

                ApprovalRecord record = new ApprovalRecord();
                record.setBusinessNumber(progress.getBusinessNumber());
                record.setFlowNumber(approvalFlow.getFlowNumber());
                record.setTableId(progress.getId());
                record.setNodeId(node1.getId());
                record.setNodeName(node1.getNodeName());
                record.setApprover(progress.getOrgName() + "(" + gcjdsq.getSqr() + ")");
                record.setApprovalTime(gcjdsq.getSqsj());
                record.setCreateTime(gcjdsq.getSqsj());
                record.setUpdateTime(gcjdsq.getSqsj());
                recordList.add(record);
            } else {
                progress.setFlowNodeId(node3.getId());
                progress.setFlowNodeName(node3.getNodeName());
                mySqlMapper.insertProgress(progress);

                ApprovalRecord record1 = new ApprovalRecord();
                record1.setBusinessNumber(progress.getBusinessNumber());
                record1.setFlowNumber(approvalFlow.getFlowNumber());
                record1.setTableId(progress.getId());
                record1.setNodeId(node1.getId());
                record1.setNodeName(node1.getNodeName());
                record1.setApprover(progress.getOrgName() + "(" + gcjdsq.getSqr() + ")");
                record1.setApprovalTime(gcjdsq.getSqsj());
                record1.setCreateTime(gcjdsq.getSqsj());
                record1.setUpdateTime(gcjdsq.getSqsj());
                record1.setDelFlag(1);

                ApprovalRecord record2 = new ApprovalRecord();
                record2.setBusinessNumber(progress.getBusinessNumber());
                record2.setFlowNumber(approvalFlow.getFlowNumber());
                record2.setTableId(progress.getId());
                record2.setNodeId(node2.getId());
                record2.setNodeName(node2.getNodeName());
                record2.setApprover("监管部门");
                record2.setApprovalTime(gcjdsq.getShsj());
                record2.setApprovalRemark(gcjdsq.getBz());
                record2.setCreateTime(gcjdsq.getShsj());
                record2.setUpdateTime(gcjdsq.getShsj());
                record2.setDelFlag(1);
                if (progress.getBusinessState() == 3) { //审核通过
                    record2.setApprovalStatus(1);
                } else { //审核驳回
                    record2.setApprovalStatus(2);
                }

                recordList.add(record1);
                recordList.add(record2);
            }

            ProgressDetail detail = new ProgressDetail(buildingAccount, currProgressConfig, gcjdsq);
            detail.setProgressBusinessId(progress.getId());
            progressDetailList.add(detail);

            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || gcjdsq.getId().equals(lastGcjdsq.getId())) { //200条数据为1组
                mySqlMapper.insertProgressDetail(progressDetailList);
                progressDetailList.clear();
                recordList.forEach(item -> System.out.println(">>>>>> item ===" + item));
                flowMapper.insertRecordBatch(recordList);
                recordList.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_progress_business、fc_progress_detail数据匹配结束=================");
    }

    /**
     * 拨付业务信息导入
     *
     * 监管拨付
     * 额度内拨付（apptype=6 flowid=4）
     * 业务表只存一条数据 监管出账通知书插入一条数据
     * -----------------------------------------------------------------------------
     * 额度外拨付（apptype=7 flowid=5）
     * 业务表只存一条数据 监管出账通知书插入一条数据
     * =============================================================================
     * 托管拨付 （托管拨付中需要监管户过渡的时候，payitem表中gdaccountid不为空）
     * 额度内拨付（apptype=18 flowid=18） 其中特批通道拨付【政府拨付】（apply表中zgflag=1）
     * 政府拨付：托管户 -> 一般户 政府发起拨付业务时只可以从托管额度内资金申请
     * 业务表只存一条数据 托管出账通知书插入一条数据
     * -----------------------------------------------------------------------------
     * 正常拨付：
     *  gdaccountid不为空时，即 托管户 -> 监管户 -> 一般户
     *  业务表插入两条数据 1.托管户->监管户 2.监管户->一般户
     *  托管出账通知书 监管入账通知书 监管出账通知书
     *
     *  gdaccountid为空时, 即 托管户 -> 账户（这里填入的可能为监管户也可能为一般户，但是统一视为一般户处理）
     *  业务表插入一条数据
     *  托管出账通知书插入一条数据
     * -----------------------------------------------------------------------------
     * 额度外拨付（apptype=19 flowid=19）
     *  gdaccountid不为空时，即 托管户 -> 监管户 -> 一般户
     *  业务表插入两条数据 1托管户->监管户 2监管户->一般户
     *  托管出账通知书 监管入账通知书 监管出账通知书
     *
     *  gdaccountid为空时, 即 托管户 -> 账户（这里填入的可能为监管户也可能为一般户，但是统一视为一般户处理）
     *  业务表插入一条数据
     *  托管出账通知书插入一条数据
     */
    @Transactional
    public void trusteeshipAppropriation() {
        System.out.println("=============== 托管拨付 =================");
        // 获取结束节点
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(4); //托管拨付申请flowType = 4
        ApprovalNode endNode = new ApprovalNode();
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        for (ApprovalNode node : approvalNodeList) {
            if (node.getNumber() == 4) {
                endNode = node;
            }
        }

        List<OracleAppropriation> oracleAppropriations = applyMapper.selectApply_18_19();

        for (OracleAppropriation oracleAppropriation : oracleAppropriations) {

            Appropriation appropriation = new Appropriation();

            // 拨付明细
            List<OracleAppropriationDetail> oracleAppropriationDetails =
                    applyMapper.selectApplyDetails_18_19(oracleAppropriation.getAppId());

            // 开发单位
            Org org = qyxxMapper.selectOrgByMisid(oracleAppropriation.getOrgMisId());
            appropriation.setOrgId(org.getId());
            appropriation.setOrgName(org.getOrgName());

            // 付款银行
            Account account = accountMapper.selectByAccountNO(
                    oracleAppropriation.getAppropriationAccount());
            appropriation.setBusinessNumber(oracleAppropriation.getBusinessNumber());
            appropriation.setBankCode(account.getBankCode());
            appropriation.setAppropriationAccountId(account.getId());
            appropriation.setAppropriationBank(account.getBankName());
            appropriation.setAppropriationName(account.getName());
            appropriation.setAppropriationAccount(account.getAccount());
            appropriation.setAppropriationOpenAddress(account.getOpenAddress());

            // 项目信息
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(oracleAppropriation.getAregId());
            appropriation.setProjectId(projectAccount.getProjectId());
            appropriation.setProjectAccountId(projectAccount.getId());
            appropriation.setProjectNumber(projectAccount.getProjectNumber());
            appropriation.setProjectName(projectAccount.getProjectName());

            // 联系人
            appropriation.setDirector(oracleAppropriation.getDirectory());
            appropriation.setPhone(oracleAppropriation.getPhone());

            // 额度内拨付
            if (oracleAppropriation.getAppType().equals(18)) {
                appropriation.setApplicationType(1);
            }

            // 额度外拨付
            if (oracleAppropriation.getAppType().equals(19)) {
                appropriation.setApplicationType(2);
            }

            if (oracleAppropriation.getZgFlag() != null &&
                    oracleAppropriation.getZgFlag().equals(1)) {
                appropriation.setAppropriationType(3); // 政府拨付
            } else {
                appropriation.setAppropriationType(1); // 托管拨付
            }

            // 托管转监管再转一般户
            if (oracleAppropriation.getSuperviseAccount() != null) {
                appropriation.setCollectionType(1);
                // 收款账户系统内查找
                Account collectionAccount = accountMapper.selectByAccountNO(
                        oracleAppropriation.getSuperviseAccount());
                if (collectionAccount != null && collectionAccount.getId() != null) {
                    appropriation.setCollectionAccountId(collectionAccount.getId());
                    appropriation.setCollectionBank(collectionAccount.getBankName());
                    appropriation.setCollectionName(collectionAccount.getName());
                    appropriation.setCollectionAccount(collectionAccount.getAccount());
                    appropriation.setCollectionOpenAddress(collectionAccount.getOpenAddress());
                }
                // 拨付状态
                if (oracleAppropriationDetails.get(0).getPayFlag2().equals(0)) {
                    appropriation.setApplicationState(0);
                }
                if (oracleAppropriationDetails.get(0).getPayFlag2().equals(1) ||
                        oracleAppropriationDetails.get(0).getPayFlag2().equals(2)) {
                    appropriation.setApplicationState(1);
                }
            } else {
                appropriation.setCollectionType(2);
                appropriation.setCollectionBank(oracleAppropriationDetails.get(0).getCollectionBank());
                appropriation.setCollectionName(oracleAppropriationDetails.get(0).getCollectionName());
                appropriation.setCollectionAccount(oracleAppropriationDetails.get(0).getCollectionAccount());
                appropriation.setApplicationState(oracleAppropriationDetails.get(0).getPayFlag());
            }

            appropriation.setPurpose(oracleAppropriationDetails.get(0).getPurpose());
            appropriation.setApplyAmount(oracleAppropriationDetails.get(0).getApplyAmountTotal());
            // 如果是流程结束
            if (oracleAppropriation.getFlowState().equals(0)) {
                appropriation.setBusinessState(3);
            }
            else if (oracleAppropriation.getFlowState().equals(1) && oracleAppropriation.getFlowNodeName().equals("保存")) {
                appropriation.setBusinessState(0);
            }
            else if (oracleAppropriation.getFlowState().equals(1) && oracleAppropriation.getFlowNodeName().equals("托管额度内资金申请上报")) {
                appropriation.setBusinessState(1);
            }
            else if (oracleAppropriation.getFlowState().equals(1) && oracleAppropriation.getFlowNodeName().equals("托管额度内资金申请初审不通过")) {
                appropriation.setBusinessState(4);
            }


            appropriation.setDelFlag(1);
            appropriation.setCreateTime(oracleAppropriation.getCreateTime());
            appropriation.setUpdateTime(oracleAppropriation.getUpdateTime());
            appropriation.setFlowNumber(approvalFlow.getFlowNumber());
            appropriation.setFlowNodeId(endNode.getId());
            appropriation.setFlowNodeName(endNode.getNodeName());

            mySqlMapper.insertAppropriation(appropriation);

            // 插入拨付明细
            List<AppropriationDetail> details = new ArrayList<>();
            for (OracleAppropriationDetail oracleAppropriationDetail : oracleAppropriationDetails) {
                AppropriationDetail appropriationDetail = new AppropriationDetail(oracleAppropriationDetail);
                appropriationDetail.setAppropriationId(appropriation.getId());
                appropriation.setCreateTime(appropriation.getCreateTime());
                appropriation.setUpdateTime(appropriation.getUpdateTime());
                details.add(appropriationDetail);
            }
            mySqlMapper.insertAppropriationDetail(details);

            // 插入审批记录
            List<ApprovalRecord> records = new ArrayList<>();
            List<OracleApprovalRecord> oracleApprovalRecords =
                    applyMapper.selectApprovalRecords_18_19(oracleAppropriation.getAppId());
            if (oracleApprovalRecords != null && oracleApprovalRecords.size() > 0
                    && oracleApprovalRecords.get(0) != null
                    && !StringUtils.isEmpty(oracleApprovalRecords.get(0).getNodeName())) {
                for (OracleApprovalRecord oracleApprovalRecord : oracleApprovalRecords) {
                    ApprovalRecord record = new ApprovalRecord();
                    record.setBusinessNumber(oracleAppropriation.getBusinessNumber());
                    record.setFlowNumber(approvalFlow.getFlowNumber());
                    record.setNodeId(endNode.getId());
                    if (!StringUtils.isEmpty(oracleApprovalRecord.getNodeName())) {
                        record.setNodeName(oracleApprovalRecord.getNodeName());
                    }
                    record.setApprover(oracleApprovalRecord.getApprover());
                    record.setApprovalTime(oracleApprovalRecord.getApprovalTime());
                    record.setTableId(appropriation.getId());
                    if (oracleApprovalRecord.getApprovalStatus() != null) {
                        record.setApprovalStatus(1);
                    }
                    record.setApprovalRemark(oracleApprovalRecord.getRemark());
                    records.add(record);
                }
                flowMapper.insertRecordBatch(records);
            }
            // 插入通知书
            // 通知书类型(type) 1托管转监管户 2托管转一般户 3托管转其他户 4监管转一般户 5监管转其他户
            mySqlMapper.insertAppropriationOutgoing(getAppropriationOutgoing(appropriation, 4));
        }
        // 更新楼幢账户表额度内已拨付金额
        mySqlMapper.updateInLimitFund();
        // 更新明细表楼幢账户主键
        mySqlMapper.updateBuildingAccountId();

        System.out.println("=============== 托管拨付数据匹配结束 =================");
    }

    @Transactional
    public void superviseAppropriation() {
        System.out.println("=============== 监管拨付 =================");
        // 获取结束节点
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(4); //托管拨付申请flowType = 4
        ApprovalNode endNode = new ApprovalNode();
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        for (ApprovalNode node : approvalNodeList) {
            if (node.getNumber() == 4) {
                endNode = node;
            }
        }
        List<OracleAppropriation> oracleAppropriations = applyMapper.selectApply_6_7();

        for (OracleAppropriation oracleAppropriation : oracleAppropriations) {

            Appropriation appropriation = new Appropriation();

            // 拨付明细
            System.out.println("======" + oracleAppropriation.getAppId());
            List<OracleAppropriationDetail> oracleAppropriationDetails =
                    applyMapper.selectApplyDetails_6_7(oracleAppropriation.getAppId());

            // 开发单位
            Org org = qyxxMapper.selectOrgByMisid(oracleAppropriation.getOrgMisId());
            appropriation.setOrgId(org.getId());
            appropriation.setOrgName(org.getOrgName());

            // 付款银行
            appropriation.setBusinessNumber(oracleAppropriation.getBusinessNumber());
            if (!StringUtils.isEmpty(oracleAppropriation.getAppropriationAccount())) {
                Account account = accountMapper.selectByAccountNO(
                        oracleAppropriation.getAppropriationAccount());
                appropriation.setBankCode(account.getBankCode());
                appropriation.setAppropriationAccountId(account.getId());
                appropriation.setAppropriationBank(account.getBankName());
                appropriation.setAppropriationName(account.getName());
                appropriation.setAppropriationAccount(account.getAccount());
                appropriation.setAppropriationOpenAddress(account.getOpenAddress());
            }
            // 项目信息
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(oracleAppropriation.getAregId());
            appropriation.setProjectId(projectAccount.getProjectId());
            appropriation.setProjectAccountId(projectAccount.getId());
            appropriation.setProjectNumber(projectAccount.getProjectNumber());
            appropriation.setProjectName(projectAccount.getProjectName());

            // 联系人
            appropriation.setDirector(oracleAppropriation.getDirectory());
            appropriation.setPhone(oracleAppropriation.getPhone());

            // 额度内拨付
            if (oracleAppropriation.getAppType().equals(6)) {
                appropriation.setApplicationType(1);
            }
            // 额度外拨付
            if (oracleAppropriation.getAppType().equals(7)) {
                appropriation.setApplicationType(2);
            }
            appropriation.setAppropriationType(2);
            appropriation.setCollectionType(2);
            if (oracleAppropriationDetails != null && oracleAppropriationDetails.size() != 0) {
                appropriation.setCollectionBank(oracleAppropriationDetails.get(0) == null ? "":oracleAppropriationDetails.get(0).getCollectionBank());
                appropriation.setCollectionName(oracleAppropriationDetails.get(0).getCollectionName());
                appropriation.setCollectionAccount(oracleAppropriationDetails.get(0).getCollectionAccount());
                appropriation.setApplicationState(oracleAppropriationDetails.get(0).getPayFlag());
                appropriation.setPurpose(oracleAppropriationDetails.get(0).getPurpose());
                appropriation.setApplyAmount(oracleAppropriationDetails.get(0).getApplyAmountTotal());
            } else {
                appropriation.setApplicationState(0);
            }

            // 如果是流程结束
            if (oracleAppropriation.getFlowState().equals(0)) {
                appropriation.setBusinessState(3);
            }
            if (oracleAppropriation.getFlowState().equals(1) && oracleAppropriation.getFlowNodeName().equals("保存")) {
                //  appropriation.setBusinessState(0);
                continue;
            }
            if (oracleAppropriation.getFlowState().equals(1) &&
                    oracleAppropriation.getFlowNodeName().equals("重点资金申请初审不通过")) {
                //  appropriation.setBusinessState(4);
                continue;
            }
            if (oracleAppropriation.getFlowState().equals(1) &&
                    oracleAppropriation.getFlowNodeName().equals("一般资金申请初审不通过")) {
                // appropriation.setBusinessState(4);
                continue;
            }

            appropriation.setDelFlag(1);
            appropriation.setCreateTime(oracleAppropriation.getCreateTime());
            appropriation.setUpdateTime(oracleAppropriation.getUpdateTime());
            appropriation.setFlowNumber(approvalFlow.getFlowNumber());
            appropriation.setFlowNodeId(endNode.getId());
            appropriation.setFlowNodeName(endNode.getNodeName());

            mySqlMapper.insertAppropriation(appropriation);

            // 插入拨付明细
            if (oracleAppropriationDetails != null && oracleAppropriationDetails.size() != 0) {
                List<AppropriationDetail> details = new ArrayList<>();
                for (OracleAppropriationDetail oracleAppropriationDetail : oracleAppropriationDetails) {
                    AppropriationDetail appropriationDetail = new AppropriationDetail(oracleAppropriationDetail);
                    appropriationDetail.setAppropriationId(appropriation.getId());
                    appropriation.setCreateTime(appropriation.getCreateTime());
                    appropriation.setUpdateTime(appropriation.getUpdateTime());
                    details.add(appropriationDetail);
                }
                mySqlMapper.insertAppropriationDetail(details);
            }

            // 插入审批记录
            List<ApprovalRecord> records = new ArrayList<>();
            List<OracleApprovalRecord> oracleApprovalRecords =
                    applyMapper.selectApprovalRecords_6_7(oracleAppropriation.getAppId());
            if (oracleApprovalRecords != null && oracleApprovalRecords.size() > 0
                    && oracleApprovalRecords.get(0) != null
                    && !StringUtils.isEmpty(oracleApprovalRecords.get(0).getNodeName())) {
                for (OracleApprovalRecord oracleApprovalRecord : oracleApprovalRecords) {
                    ApprovalRecord record = new ApprovalRecord();
                    record.setBusinessNumber(oracleAppropriation.getBusinessNumber());
                    record.setFlowNumber(approvalFlow.getFlowNumber());
                    record.setNodeId(endNode.getId());
                    if (!StringUtils.isEmpty(oracleApprovalRecord.getNodeName())) {
                        record.setNodeName(oracleApprovalRecord.getNodeName());
                    }
                    record.setApprover(oracleApprovalRecord.getApprover());
                    record.setApprovalTime(oracleApprovalRecord.getApprovalTime());
                    record.setTableId(appropriation.getId());
                    if (oracleApprovalRecord.getApprovalStatus() != null) {
                        record.setApprovalStatus(Integer.parseInt(oracleApprovalRecord.getApprovalStatus()));
                    }
                    record.setApprovalRemark(oracleApprovalRecord.getRemark());
                    records.add(record);
                }
                flowMapper.insertRecordBatch(records);
            }
            // 插入通知书
            // 通知书类型(type) 1托管转监管户 2托管转一般户 3托管转其他户 4监管转一般户 5监管转其他户
            if (oracleAppropriation.getSuperviseAccount() != null) {
                mySqlMapper.insertAppropriationOutgoing(getAppropriationOutgoing(appropriation, 1));
                mySqlMapper.insertAppropriationPosting(getAppropriationPosting(appropriation));
            } else {
                mySqlMapper.insertAppropriationOutgoing(getAppropriationOutgoing(appropriation, 2));
            }
        }

        System.out.println("=============== 监管拨付数据匹配结束 =================");
    }

    //拨付出账通知书
    public AppropriationOutgoing getAppropriationOutgoing(Appropriation appropriation, Integer type) {
        AppropriationNotice notice = new AppropriationNotice();
        notice.initNotice(appropriation);

        AppropriationOutgoing outgoing = new AppropriationOutgoing();
        outgoing.initNotice(appropriation, type);
        return outgoing;
    }

    //拨付入账通知书
    public AppropriationPosting getAppropriationPosting(Appropriation appropriation) {
        AppropriationNotice notice = new AppropriationNotice();
        notice.initNotice(appropriation);

        AppropriationPosting posting = new AppropriationPosting();
        posting.initNotice(appropriation);
        return posting;
    }


    /**
     * 合同导入
     */
    @Transactional
    public void htTo() {
        System.out.println("===============fc_contract 导入数据开始=================");
        Long a = new Date().getTime();
        List<HtInfo> htInfoList = oracleMapper.selectHtInfo();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("查询到：" + htInfoList.size() + "条");
        System.out.println("查询耗时：" + (b - a) / 1000);


        HtInfo lastHtInfo = htInfoList.get(htInfoList.size() - 1);

        List<Contract> contracts = new ArrayList<>();

        int index = 0;

        for (HtInfo item : htInfoList) {
            Contract contract = new Contract();

            // 查询企业
            Org org = qyxxMapper.selectOrgByMisid(Integer.parseInt(item.getQYBH()));
            contract.setOrgId(org.getId());
            contract.setOrgName(org.getOrgName());

            // 查询楼幢虚拟户
            BuildingAccount building = buildingAccountMapper.getInfoByLZBH(item.getLZBH());
            contract.setBuildingId(building.getBuildingId());
            contract.setBuildingAccountId(building.getId());
            contract.setBuildingNumber(building.getBuildingNumber());
            contract.setBuildingName(building.getBuildingName());

            // 查询项目虚拟户
            ProjectAccount project = projectAccountMapper.getInfoById(building.getProjectAccountId());
            contract.setProjectId(project.getProjectId());
            contract.setProjectAccountId(project.getId());
            contract.setProjectNumber(project.getProjectNumber());
            contract.setProjectName(project.getProjectName());

            // 查询房屋信息
            P_lpb_fw fw = fwMapper.getFwByMissid(item.getFWBH(),1);

            // 查询交易表
            List<BhtTrade> bhtTrades = oracleMapper.getBhtPayTradeByBHTID(item.getHTID());

            String bankAccount = "";
            BigDecimal amount = new BigDecimal("0");
            for (BhtTrade bhtTrade : bhtTrades) {
                amount = amount.add(bhtTrade.getJkje());
                if (bankAccount.equals("") && bhtTrade.getPayType().equals(1)) {
                    bankAccount = bhtTrade.getBankAccount();
                }
            }

            contract.initValueConfig(item, fw, bhtTrades);

            // 银行
            if (!StringUtils.isEmpty(bankAccount)) {
                Account account = accountMapper.selectByAccountNO(bankAccount);
                contract.setAccountId(account.getId());
                contract.setAccountType(account.getType());
                contract.setBankCode(account.getBankCode());
                contract.setCollectionBank(account.getBankName());
                contract.setCollectionName(account.getName());
                contract.setCollectionAccount(account.getAccount());
                contract.setCollectionOpenAddress(account.getOpenAddress());
            } else {
                System.out.println(" >>>>>>>> 快来看看，你的数据："+ item.getHTID());
            }

            contracts.add(contract);

            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || item.getHTID().equals(lastHtInfo.getHTID())) { //200条数据为1组
                mySqlMapper.insertContract(contracts);
                contracts.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_Contract数据匹配结束=================");
    }


    /**
     * 交存导入
     */
    @Transactional
    public void htPayTo() {
        System.out.println("===============fc_fund 导入数据开始=================");
        Long a = new Date().getTime();
        List<HtPay> htPayList = oracleMapper.selectHtPayInfo();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("查询到：" + htPayList.size() + "条");
        System.out.println("查询耗时：" + (b - a) / 1000);


        HtPay lastHtPay = htPayList.get(htPayList.size() - 1);

        List<Fund> funds = new ArrayList<>();

        int index = 0;
        for (HtPay item : htPayList) {
            Account account = accountMapper.selectByAccountNO(item.getACCOUNTNO());
            Long newContractId = mySqlMapper.getContractIdByNumber(item.getHTBH());
            List<BhtTrade> bhtTrades = oracleMapper.getTradeByBHTPayJKBH(item.getJKBH());
            Fund fund = new Fund(account, item, newContractId, bhtTrades);
            funds.add(fund);
            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || item.getHTPAYID().equals(lastHtPay.getHTPAYID())) { //200条数据为1组
                mySqlMapper.insertFund(funds);
                funds.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_Fund数据匹配结束=================");
    }


    /**
     * 定金导入
     */
    @Transactional
    public void djTo() {
        System.out.println("===============fc_earnest 导入数据开始=================");
        Long a = new Date().getTime();
        List<BDj> djList = oracleMapper.selectBDJInfo();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("查询到：" + djList.size() + "条");
        System.out.println("查询耗时：" + (b - a) / 1000);


        BDj lastDj = djList.get(djList.size() - 1);

        List<Earnest> earnests = new ArrayList<>();

        int index = 0;
        for (BDj item : djList) {
            Integer qybh = StringUtils.isEmpty(item.getQYBH()) ? null : Integer.valueOf(item.getQYBH());
            Org org = qyxxMapper.selectOrgByMisid(qybh);
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            BuildingAccount buildingAccount = null;
            if (!StringUtils.isEmpty(item.getLZBH())) {
                buildingAccount = buildingAccountMapper.getInfoByLZBH(item.getLZBH());
            }
            Long projectAccountId = (null != buildingAccount && null != buildingAccount.getProjectAccountId()) ? buildingAccount.getProjectAccountId() : null;
            ProjectAccount projectAccount = null;
            if (null != projectAccountId) {
                projectAccount = projectAccountMapper.getInfoById(projectAccountId);
            }
            Account account = null;
            if (!StringUtils.isEmpty(item.getACCOUNTNO())) {
                account = accountMapper.selectByAccountNO(item.getACCOUNTNO());
            }
//            //BDJ TRADESTATE  是2但是TRADENUM 没有的  是退款的    BDJ 的TRADESTATE  应该是-2  退款
//            if (!StringUtils.isEmpty(item.getTRADESTATE()) && "2".equals(item.getTRADESTATE()) && StringUtils.isEmpty(item.getTRADENUM())) {
//                item.setTRADESTATE("-2");
//            }
            Earnest earnest = new Earnest(item, buildingAccount, projectAccount, account, org);
            earnests.add(earnest);
            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || item.getDJID().equals(lastDj.getDJID())) { //200条数据为1组
                mySqlMapper.insertEarnest(earnests);
                earnests.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_earnest数据匹配结束=================");
    }

    public void bankBill(String bankCode, String startDate, String endDate) {
        List<BankBill> bills = mySqlMapper.selectByBankBill(bankCode, startDate, endDate);
        List<String> strs = new ArrayList<>(1844);
        strs.add("编号;账号;收入;支出;时间;类型");
        for (BankBill item : bills) {
            StringBuilder str = new StringBuilder();
            str.append(item.getBusinessNumber())
                    .append(";" + item.getAccount())
                    .append(";" + (item.getType().equals(1)?item.getAmount():0))
                    .append(";" + (item.getType().equals(1)?0:item.getAmount()))
                    .append(";" + item.getTransactionTime())
                    .append(";" + (item.getType().equals(1)?"收入":"支出"));
            strs.add(str.toString());
        }
        strs.forEach(System.out::println);
        System.out.println("总计："+ strs.size());
    }

    public void selectOrgAccount() {
        List<String> strs = new ArrayList<>();
        strs.add("开发单位;项目;银行;账户;账号");
        List<OrgAccount> orgList = mySqlMapper.selectOrgList();
        orgList.forEach(item -> {
            StringBuilder str = new StringBuilder();
            str.append(item.getOrgName())
                    .append(";" + item.getBankName())
                    .append(";" + item.getProjectName())
                    .append(";" + item.getName())
                    .append(";" + item.getAccount())
                    ;
            strs.add(str.toString());
        });
        strs.forEach(System.out::println);
    }

    public void projectAccount2 () {
        List<ProjectAccountTrade> payments = mySqlMapper.selectPaymentTrade();

        BigDecimal ba = new BigDecimal("0");

        for (ProjectAccountTrade item : payments) {
            ba = ba.add(item.getAmount());
        }
        System.out.println(ba);


        List<ProjectAccountTrade> appropriations = mySqlMapper.selectAppropriationTrade();

        BigDecimal pa = new BigDecimal("0");

        for (ProjectAccountTrade item : appropriations) {
            pa = pa.add(item.getAmount());
        }
        System.out.println(pa);


        List<ProjectAccountTrade> projectBalances = mySqlMapper.selectProjectAccount();

        List<ProjectAccountTrade> amounts = new ArrayList<>();
        for (ProjectAccountTrade payment : payments) {
            ProjectAccountTrade t = new ProjectAccountTrade();
            t.setId(payment.getId());
            t.setAmount(payment.getAmount());
            for (ProjectAccountTrade appropriation : appropriations) {
                if (appropriation.getId().equals(payment.getId())) {
                    t.setId(appropriation.getId());
                    t.setAmount(payment.getAmount().subtract(appropriation.getAmount()));
                }
            }
            amounts.add(t);
        }

        List<String> strs = new ArrayList<>();

        for (ProjectAccountTrade item : amounts) {
            StringBuffer str = new StringBuffer();
            str.append(item.getId());
            str.append(";").append(item.getAmount());
                for (ProjectAccountTrade balance : projectBalances) {
                    if (balance.getId().equals(item.getId())) {
                        str.append(";").append(balance.getAmount())
                                .append(";").append(item.getAmount().compareTo(balance.getAmount()))
                                .append(";").append(item.getAmount().subtract(balance.getAmount()));

                    }
                }
            strs.add(str.toString());
        }

        strs.forEach(System.out::println);
    }
}
